<?php

namespace Drupal\site_settings_domain\Hook;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Hooks onto entity_base_field_info events.
 */
final class EntityBaseFieldInfo {

  use StringTranslationTrait;

  #[Hook('entity_base_field_info')]
  public function entityBaseFieldInfo(EntityTypeInterface $entity_type): array {
    if ($entity_type->id() !== 'site_setting_entity') {
      return [];
    }

    // Add the domain context field.
    $fields['domain_context'] = BaseFieldDefinition::create('entity_reference')
      ->setName('domain_context')
      ->setLabel($this->t('Domain context'))
      ->setDescription($this->t('The domain context for this site setting. Leaving this empty will make the site setting serve as a "fallback" when a more specific site setting isn\'t available'))
      ->setSetting('target_type', 'domain')
      ->setSetting('handler', 'default')
      ->setDisplayConfigurable('form', FALSE)
      ->setDisplayOptions('form', [
        'type' => 'options_buttons',
      ])
      ->setDisplayConfigurable('view', FALSE)
      ->setTranslatable(FALSE);

    // Add the domain context parent field, this lets items be linked to eachother.
    $fields['domain_context_parent'] = BaseFieldDefinition::create('entity_reference')
      ->setName('domain_context_parent')
      ->setLabel($this->t('Domain context parent'))
      ->setDescription($this->t('The domain context parent entity for this site setting.'))
      ->setSetting('target_type', 'site_setting_entity')
      ->setSetting('handler', 'default')
      ->setDisplayConfigurable('form', FALSE)
      ->setDisplayConfigurable('view', FALSE)
      ->setTranslatable(FALSE);

    return $fields;
  }

}
