<?php

namespace Drupal\site_settings_domain\Hook;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\site_settings\SiteSettingEntityInterface;

/**
 * Hooks onto entity_predelete events.
 */
final readonly class EntityPredelete {

  /**
   * Constructs the hook class.
   */
  public function __construct(
    private EntityTypeManagerInterface $entityTypeManager,
  ) {}

  #[Hook('site_setting_entity_predelete')]
  public function preDeleteSiteSettingEntity(SiteSettingEntityInterface $site_setting_entity): void {
    if (!$site_setting_entity->get('domain_context_parent')->isEmpty()) {
      return;
    }

    // Load linked site settings.
    $storage = $this->entityTypeManager->getStorage('site_setting_entity');
    $ids = $storage->getQuery()
      ->accessCheck(FALSE)
      ->condition('domain_context_parent', $site_setting_entity->id())
      ->execute();

    // There's no site settings linked to the one that's about to be deleted.
    if (empty($ids)) {
      return;
    }

    // Set the first linked site setting as the new parent.
    $new_parent = $storage->load(array_shift($ids));
    $new_parent->set('domain_context_parent', NULL);
    $new_parent->save();

    // Move all the other linked site settings to the new parent.
    foreach ($ids as $id) {
      $linked_site_setting = $storage->load($id);
      $linked_site_setting->set('domain_context_parent', $new_parent->id());
      $linked_site_setting->save();
    }
  }

}
