<?php

namespace Drupal\site_settings_domain\Plugin\Block;

use Drupal\Core\Block\Attribute\Block;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\site_settings\Plugin\Block\RenderedSiteSettingsBlock as RenderedSiteSettingsBlockBase;
use Drupal\site_settings_domain\Plugin\SiteSettingsLoader\FullSiteSettingsLoader;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'RenderedSiteSettingsBlock' block.
 */
#[Block(
  id: "single_rendered_site_settings_domain_block",
  admin_label: new TranslatableMarkup("Rendered site settings block (domain context)")
)]
class RenderedSiteSettingsBlock extends RenderedSiteSettingsBlockBase {

  private FullSiteSettingsLoader $loader;

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->loader = $container->get('plugin.manager.site_settings_loader')->getPlugin('full_domain');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    $build = [
      '#cache' => [
        'tags' => ['site_setting_entity_list'],
        'contexts' => ['languages'],
      ],
    ];

    $entities = $this->loader->loadByType($this->configuration['setting']);

    if (empty($entities)) {
      return $build;
    }

    $view_builder = $this->entityTypeManager->getViewBuilder('site_setting_entity');
    $view_mode = $this->configuration['view_mode'] ?: 'default';

    // Loop through the entities and their fields.
    foreach ($entities as $entity) {
      $pre_render = $view_builder->view($entity, $view_mode);
      $item_build = $view_builder->build($pre_render);

      $build[] = $item_build;
    }

    return $build;
  }

}
