<?php

namespace Drupal\site_settings_domain\Plugin\Block;

use Drupal\site_settings\Plugin\Block\SimpleSiteSettingsBlock as SimpleSiteSettingsBlockBase;

/**
 * Provides a 'SimpleSiteSettingsBlock' block.
 *
 * @Block(
 *  id = "simple_site_settings_domain_block",
 *  admin_label = @Translation("Simple site settings block (domain context)"),
 * )
 */
class SimpleSiteSettingsBlock extends SimpleSiteSettingsBlockBase {

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   *   Thrown if the entity type doesn't exist.
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Exception
   *   Thrown if the storage handler couldn't be loaded.
   */
  public function build(): array {
    $build = [
      '#cache' => [
        'tags' => ['site_setting_entity_list'],
      ],
    ];

    $base_fields = [];

    // Get all settings in the selected bundle.
    /** @var \Drupal\site_settings_domain\Plugin\SiteSettingsLoader\FullSiteSettingsLoader $loader */
    $loader = $this->pluginManager->getPlugin('full_domain');
    $entities = $loader->loadByType($this->configuration['setting']);

    if (empty($entities)) {
      return $build;
    }

    // Loop through the entities and their fields.
    foreach ($entities as $entity) {
      /** @var \Drupal\site_settings\SiteSettingEntityInterface $entity */

      // Determine which fields to exclude from render.
      if (!$base_fields) {
        $base_fields = array_keys($entity->getEntityType()->getKeys());
        $base_fields = array_merge($base_fields, [
          'name',
          'user_id',
          'type',
          'created',
          'changed',
        ]);
      }

      // Maintain backwards compatibility for site settings block with
      // flattened loader which previously set default image size output.
      if (method_exists($loader, 'setDefaultImageSizeOutput')) {

        // Get the renderer for a basic rendering. Users can use the templating
        // system to do something more advanced.
        $loader->setDefaultImageSizeOutput(400, 400);
      }

      $fields = $entity->getFields();
      foreach ($fields as $key => $field) {
        // Exclude base fields from output.
        if (!in_array($key, $base_fields)
          && method_exists(get_class($field), 'getFieldDefinition')
          && method_exists($loader, 'renderField')) {
          $build[] = [
            '#markup' => $loader->renderField($field),
          ];
        }
      }
    }

    return $build;
  }

}
